#coding=utf-8
import sys
import json

from fdmutils.common     import get_tb_info
from fdmutils.common     import show_dict_intree
from fdmutils.data_var   import my_linf    ## 负无穷
from fdmutils.data_var   import my_rinf    ## 正无穷

class CAddNumberObj():
    def __init__(self,_debug=False):
        self.debug = _debug
        pass

    def add(self,a,b):
        """
        @note   : 加法运算
        @param a: 数值型变量
        @param b: 数值型变量
        @return dst: 结果
        """
        msg     = "success"
        flag    = 0
        dst     = 0

        try:
            dst  = a+b
        except:
            msg  = get_tb_info()
            flag = -1
            dst  = None
        return msg,flag,dst




if __name__ == "__main__":
    print("call CAddNumberObj")
    sys.exit(0)



#coding=utf-8
import io
import traceback
import json
import math
#import pandas
#import configparser
#import logging
#from logging import handlers
import os
import sys



##<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
## 函数部分
## get_tb_info              获取异常的细节，帮助调试代码
## show_dict_intree         以树的形式，可视化一个字典
## debug_line               调试时打印分行符，【"\t"*30 + "**"*30】 
## is_number                输入字符串,是否为数字
##<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
def get_tb_info():
    message = traceback.format_exc()
    return message

def show_dict_intree(_input_dict):
    print(json.dumps(_input_dict, indent=2)) 

def debug_line():
    print("\t"*30)
    print("**"*30)
    return 0

def is_number(_value):
    flag = True
    try:
        c = float(_value)
        c += 1
        if math.isnan(c):
            flag = False
        else:
            flag = True
    except:
        flag = False
    return flag



#coding=utf-8
import sys
import os
import inspect

sys.path.append(os.path.abspath(os.path.dirname(__file__)))
from common import get_tb_info

class CTemplate(object):
    def __init__(self,ruleconf={}):
        self.m_ruleconf = ruleconf

    def hello(self):
        # print("CTemplate:hello")
        return 0

    def compute(self, *args, **kwargs):
        rule_name = kwargs.get('rule_name')
        if rule_name not in dir(self):
            msg = "类{0}的函数中没有[{1}]".format(type(self).__name__, rule_name)
            result = {"result": 1, "data": -1, "message": msg}
        elif rule_name not in self.m_ruleconf:
            msg = "配置文件rule.yaml中，没有该变量[{0}]".format(rule_name)
            result = {"result": 1, "data": -1, "message": msg}
        else:
            try:
                ## 监听函数地址
                _handler = getattr(self, rule_name)

                ## 获取监听函数参数
                _handler_params = inspect.signature(_handler).parameters

                ## 下游函数解析
                _handle_kwargs = {}
                if "kwargs" in _handler_params:
                    _handle_kwargs.update(kwargs)
                else:
                    other_params = {key: kwargs.get(key) for key in kwargs if key in _handler_params}
                    _handle_kwargs.update(other_params)

                result = _handler(*args, **_handle_kwargs)

            except:
                msg = get_tb_info()
                result = {"result": 1, "data": -1, "message": msg}
        return result


if __name__ == "__main__":
    pass



#coding=utf-8
import io
import traceback
import json
import math
import pandas
import configparser
import logging
from logging import handlers
import os
import sys
sys.path.append(os.path.abspath(os.path.dirname(__file__)))

from common import get_tb_info
from common import debug_line

class LogLevelFilter(logging.Filter):
    def __init__(self, name='', level=logging.DEBUG):
        super(LogLevelFilter,self).__init__(name)
        self.level = level

    def filter(self, record):
        return record.levelno == self.level
##<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
## 函数部分
## init_log_from_config     从配置文件中，获取日志配置。【特殊参数_root_dir】
## read_config              从配置文件中，获取需要解析的特征
##<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
def init_log_from_config(_config_path,_root_dir=""):
    msg     = "success"
    flag    = 0
    logger  = None
    try:
        config = configparser.ConfigParser()
        config.read(_config_path)

        module      = config.get('log','module',raw=True)
        base_dir    = config.get('log','base',raw=True).format(ROOT_DIR=_root_dir)
        pout_info   = os.path.join(base_dir,config.get('log','info',raw=True))
        pout_debug  = os.path.join(base_dir,config.get('log','debug',raw=True))
        pout_error  = os.path.join(base_dir,config.get('log','error',raw=True))

        logger = logging.getLogger(module)
        logger.setLevel(logging.DEBUG)

        formatter = logging.Formatter("%(asctime)s %(name)s %(levelname)s %(message)s",datefmt="%Y-%m-%d %H:%M:%S")

        fh_info  = handlers.TimedRotatingFileHandler(pout_info, when="midnight", interval=1, backupCount=3)
        fh_info.setLevel(logging.INFO)
        fh_debug = handlers.TimedRotatingFileHandler(pout_debug, when="midnight", interval=1, backupCount=3)
        fh_debug.setLevel(logging.DEBUG)
        fh_error = handlers.TimedRotatingFileHandler(pout_error, when="midnight", interval=1, backupCount=3)
        fh_error.setLevel(logging.ERROR)

        filter_info  = LogLevelFilter(level=logging.INFO)
        filter_debug = LogLevelFilter(level=logging.DEBUG)
        filter_error = LogLevelFilter(level=logging.ERROR)

        fh_info.addFilter(filter_info)
        fh_debug.addFilter(filter_debug)
        fh_error.addFilter(filter_error)
        fh_info.setFormatter(formatter)
        fh_debug.setFormatter(formatter)
        fh_error.setFormatter(formatter)

        logger.addHandler(fh_info)
        logger.addHandler(fh_debug)
        logger.addHandler(fh_error)
    except:
        msg     = get_tb_info()
        flag    = -1
        logger  = None

    return msg,flag,logger

def read_config(_config_path):
    msg     = "success"
    flag    = 0
    config  = None
    try:
        config = configparser.ConfigParser()
        config.read(_config_path)
    except:
        msg     = get_tb_info()
        flag    = -1
        config  = None
    return msg,flag,config

##<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
## 变量部分
## logger               ##打印日志的全局变量，从log.conf中解析 
## config               ##特征配置的全局变量，从feature.conf中解析 
##<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
"""
CURRENT_DIR     = os.path.abspath(os.path.dirname(__file__))
ROOT_DIR        = os.path.join(CURRENT_DIR, '../../')
CONFIG_LOG      = os.path.join(ROOT_DIR,"conf/log.conf")
CONFIG_FEATURE  = os.path.join(ROOT_DIR,"conf/feature.conf")
msg,flag,logger = init_log_from_config(CONFIG_LOG,_root_dir=ROOT_DIR)
msg,flag,config = read_config(CONFIG_FEATURE)
"""





from setuptools import setup, find_packages

setup(
    name='safexzutils',
    version='0.1.3',
    author='safeutils',
    author_email='back_man007@163.com',
    packages=["safexzutils"],
    license='LICENSE.txt',
    description='independent functions',
    long_description=open('README.md').read(),
    python_requires='>=3',
)
